@@ -1,4 +1,4 @@
-# $Id: mvt.R,v 1.17 2002/01/24 12:18:11 hothorn Exp $ 
+# $Id: mvt.R,v 1.20 2002/04/09 14:16:48 hothorn Exp $ 
 
 checkmvArgs <- function(lower, upper, mean, corr, sigma) 
 {
@@ -81,7 +81,7 @@ pmvnorm <- function(lower=-Inf, upper=Inf, mean=rep(0, length(lower)), corr=NULL
           lower <- (carg$lower - carg$mean)/sqrt(diag(carg$sigma))
           upper <- (carg$upper - carg$mean)/sqrt(diag(carg$sigma))
           mean <- rep(0, length(lower))
-          corr <- t(t(carg$sigma)/diag(carg$sigma))
+          corr <- sig2corr(carg$sigma)
           RET <- mvt(lower=lower, upper=upper, df=0, corr=corr, delta=mean,
                      maxpts=maxpts, abseps=abseps,releps=releps)
       }
@@ -108,13 +108,15 @@ pmvt <- function(lower=-Inf, upper=Inf, delta=rep(0, length(lower)),
     } else {
         if (!is.null(carg$corr)) {
             RET <- mvt(lower=carg$lower, upper=carg$upper, df=df, corr=carg$corr,
-                       delta=carg$mean,  maxpts=maxpts, abseps=abseps,releps=releps)
+                       delta=carg$mean,  maxpts=maxpts,
+                       abseps=abseps,releps=releps)
         } else {
             lower <- carg$lower/sqrt(diag(carg$sigma))
             upper <- carg$upper/sqrt(diag(carg$sigma))
-            corr <- t(t(sigma)/diag(carg$sigma))
+            corr <- sig2corr(carg$sigma)
             RET <- mvt(lower=lower, upper=upper, df=df, corr=corr,
-                       delta=carg$mean, maxpts=maxpts, abseps=abseps,releps=releps)
+                       delta=carg$mean, maxpts=maxpts,
+                       abseps=abseps,releps=releps)
         }
     }
     attr(RET$value, "error") <- RET$error
@@ -152,7 +154,7 @@ mvt <- function(lower, upper, df, corr, delta, maxpts = 25000,
     ret <- .Fortran("mvtdst", as.integer(n), as.integer(df),
                         as.double(lower), as.double(upper), as.integer(infin),
                         as.double(corrF), as.double(delta), as.integer(maxpts),
-                        as.double(abseps), as.double(releps),
+                        as.double(abseps), as.double(releps),  
                         error = as.double(error), value = as.double(value),
                         inform = as.integer(inform))
     
